<?php
/*
Plugin Name: ChefGPT Recipes Fetcher
Plugin URI: https://chatgpt.fr
Description: Plugin pour récupérer et afficher les recettes de ChatGPT.fr via un shortcode avec une présentation esthétique.
Version: 1.0.2
Author: Groupe Coste
Author URI: https://groupe-coste.fr
License: GPLv2 or later
Text Domain: chefgpt-recipes-fetcher
*/

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}

class ChefGPT_Recipes_Fetcher {
    private $api_url = 'https://chefgpt.fr/wp-json/chefgpt/v1/recipes'; // URL de l'API REST de ChatGPT.fr

    public function __construct() {
        add_shortcode('chefgpt_recipes', array($this, 'render_recipes_shortcode'));
        add_action('wp_enqueue_scripts', array($this, 'enqueue_styles'));
    }

    /**
     * Enqueue styles pour le plugin
     */
   public function enqueue_styles() {
    // Définir le chemin vers le fichier CSS
    $css_file = plugin_dir_url(__FILE__) . 'assets/style.css';
    
    // Enregistrer le style
    wp_register_style('chefgpt-recipes-fetcher-styles', $css_file, array(), '1.0.0');
    
    // Enqueue le style
    wp_enqueue_style('chefgpt-recipes-fetcher-styles');
}

    /**
     * Rendu du shortcode [chefgpt_recipes]
     *
     * @param array $atts Attributs du shortcode.
     * @return string HTML des recettes et de la pagination.
     */
   /**
 * Rendu du shortcode [chefgpt_recipes]
 *
 * @param array $atts Attributs du shortcode.
 * @return string HTML des recettes et de la pagination.
 */
public function render_recipes_shortcode($atts) {
    $atts = shortcode_atts(array(
        'per_page' => 10
    ), $atts, 'chefgpt_recipes');

    // Récupérer la page courante depuis la query string
    $page = isset($_GET['chefgpt_page']) ? intval($_GET['chefgpt_page']) : 1;
    $per_page = intval($atts['per_page']);

    // Valider les valeurs
    if ($page < 1) {
        $page = 1;
    }
    if ($per_page < 1) {
        $per_page = 10;
    }

    // Construire l'URL avec les paramètres de pagination
    $request_url = add_query_arg(array(
        'page' => $page,
        'per_page' => $per_page
    ), $this->api_url);

    // Vérifier si les données sont mises en cache (optionnel pour améliorer les performances)
    $transient_key = "chefgpt_rf_recipes_page_{$page}_perpage_{$per_page}";
    $data = get_transient($transient_key);

    if (false === $data) {
        // Faire la requête GET à l'API
        $response = wp_remote_get($request_url, array(
            'timeout' => 15,
        ));

        // Vérifier si la requête a échoué
        if (is_wp_error($response)) {
            return '<p>' . esc_html($response->get_error_message()) . '</p>';
        }

        // Vérifier le code de réponse HTTP
        $status_code = wp_remote_retrieve_response_code($response);
        if ($status_code != 200) {
            return '<p>Erreur lors de la récupération des recettes. Code de réponse : ' . esc_html($status_code) . '</p>';
        }

        // Récupérer le corps de la réponse
        $body = wp_remote_retrieve_body($response);
        $data = json_decode($body, true);

        // Vérifier si le décodage JSON a échoué
        if (json_last_error() !== JSON_ERROR_NONE) {
            return '<p>Erreur lors du décodage de la réponse JSON.</p>';
        }

        // Stocker dans le cache pendant 5 minutes (optionnel)
        set_transient($transient_key, $data, 5 * MINUTE_IN_SECONDS);
    }

    // Récupérer les données nécessaires
    $recipes = isset($data['data']) ? $data['data'] : array();
    $total_pages = isset($data['total_pages']) ? intval($data['total_pages']) : 1;
    $current_page = isset($data['current_page']) ? intval($data['current_page']) : 1;

    // Vérifier si des recettes ont été retournées
    if (empty($recipes)) {
        return '<p>Aucune recette trouvée.</p>';
    }

    // Générer le HTML des recettes
    ob_start();
    echo '<div class="chefgpt-recipes-container">';
    echo '<div class="chefgpt-recipes-grid">';
    foreach ($recipes as $recipe) {
        $title = isset($recipe['title']) ? sanitize_text_field($recipe['title']) : 'Sans titre';
        $link = isset($recipe['link']) ? esc_url($recipe['link']) : '#';
        $image_url = isset($recipe['image_url']) ? esc_url($recipe['image_url']) : 'https://via.placeholder.com/300x150?text=Aucune+Image';
        ?>
        <div class="chefgpt-recipe-card">
            <a href="<?php echo $link; ?>" target="_blank">
                <img src="<?php echo $image_url; ?>" alt="<?php echo esc_attr($title); ?>">
                <div class="chefgpt-recipe-content">
                    <h3 class="chefgpt-recipe-title"><?php echo esc_html($title); ?></h3>
                </div>
            </a>
        </div>
        <?php
    }
    echo '</div>'; // Fin de chefgpt-recipes-grid

    // Gestion de la pagination
    if ($total_pages > 1) {
        echo '<div class="chefgpt-recipes-pagination">';
        // Lien précédent
        if ($current_page > 1) {
            $prev_page = $current_page - 1;
            echo '<a href="' . esc_url(add_query_arg('chefgpt_page', $prev_page)) . '">&laquo; Précédent</a>';
        }

        // Afficher les numéros de page (limiter le nombre affiché si trop grand)
        $max_pages_to_show = 5;
        $start_page = max(1, $current_page - floor($max_pages_to_show / 2));
        $end_page = min($total_pages, $start_page + $max_pages_to_show - 1);

        // Ajuster si nous sommes en fin de série
        if ($end_page - $start_page < $max_pages_to_show - 1) {
            $start_page = max(1, $end_page - $max_pages_to_show + 1);
        }

        if ($start_page > 1) {
            echo '<a href="' . esc_url(add_query_arg('chefgpt_page', 1)) . '">1</a>';
            if ($start_page > 2) {
                echo '<span>...</span>';
            }
        }

        for ($i = $start_page; $i <= $end_page; $i++) {
            if ($i == $current_page) {
                echo '<a href="' . esc_url(add_query_arg('chefgpt_page', $i)) . '" class="current">' . $i . '</a>';
            } else {
                echo '<a href="' . esc_url(add_query_arg('chefgpt_page', $i)) . '">' . $i . '</a>';
            }
        }

        if ($end_page < $total_pages) {
            if ($end_page < $total_pages - 1) {
                echo '<span>...</span>';
            }
            echo '<a href="' . esc_url(add_query_arg('chefgpt_page', $total_pages)) . '">' . $total_pages . '</a>';
        }

        // Lien suivant
        if ($current_page < $total_pages) {
            $next_page = $current_page + 1;
            echo '<a href="' . esc_url(add_query_arg('chefgpt_page', $next_page)) . '">Suivant &raquo;</a>';
        }
        echo '</div>'; // Fin de chefgpt-recipes-pagination
    }

    // Ajouter le lien "Propulsé par ChefGPT.fr"
    echo '<div class="chefgpt-powered-by">Propulsé par <a href="https://chefgpt.fr" target="_blank">ChefGPT.fr</a></div>';
    echo '</div>'; // Fin de chefgpt-recipes-container

    return ob_get_clean();
}
}

new ChefGPT_Recipes_Fetcher();